==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/space/messages/ar/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '<b>هذه المساحة لا تزال فارغة!</b>',
    '<b>This space is still empty!</b><br>Start by posting something here...' => 'هذه الباحة تخلو من المحتويات! <br>يمكنك البدء و كتابة شيء ما...',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>أنت لست عضوًا في هذه المساحة ولا يوجد محتوى عام حتى الآن!</b>',
    '<strong>Confirm</strong> image deletion' => 'حذف الصورة <strong>تأكيد</strong>',
    '<strong>Invite</strong> members' => 'أفراد <strong>دعوة</strong>',
    '<strong>New</strong> member request' => 'طلب عضو <strong>جديد</strong>',
    '<strong>New</strong> spaces' => 'باحة <strong>جديد</strong>',
    '<strong>Request</strong> space membership' => 'عضوية الفضاء <strong>طلب</strong> ',
    '<strong>Space</strong> followers' => 'المتابعون <strong>باحة</strong>',
    '<strong>Space</strong> members' => 'الاعضاء <strong>باحة</strong>',
    '<strong>Space</strong> menu' => 'المنيو <strong>باحة</strong>',
    'About' => 'عن',
    'Accept' => 'موافقة',
    'Accept Invite' => 'قبول دعوة',
    'Add users without invitation' => 'أضف مستخدمين بدون دعوة',
    'Admin' => 'مشرف',
    'Administrator:' => 'مدير:',
    'Administrators' => 'المسؤولون',
    'Application message' => 'رسالة التطبيق',
    'Archived' => 'أرشيف',
    'As owner you cannot revoke your membership!' => 'كمالك لا يمكنك إلغاء عضويتك!',
    'Cancel' => 'إلغاء',
    'Close' => 'اغلاق',
    'Color' => 'الون',
    'Could not request membership!' => 'تعذر طلب العضوية!',
    'Created At' => 'أنشئت في',
    'Created By' => 'تم وضعه بواسطة',
    'Decline' => 'رفض',
    'Decline Invite' => 'رفض الدعوة',
    'Default' => 'الإفتراضي',
    'Default content visibility' => 'رؤية المحتوى الافتراضي',
    'Delete' => 'حذف',
    'Description' => 'توضيج',
    'Do you really want to delete your profile image?' => 'هل تريد حقًا حذف صورة ملفك الشخصي؟',
    'Do you really want to delete your title image?' => 'هل تريد حقًا حذف صورة العنوان؟',
    'Done' => 'تم',
    'Email addresses' => 'البريد الالكترونى',
    'Everyone can enter' => 'يمكن للجميع الدخول',
    'Follow' => 'متابعة',
    'Followers' => 'متابعون',
    'Following' => 'التالية',
    'Homepage' => 'الصفحة الرئيسية',
    'Homepage (Guests)' => 'الصفحة الرئيسية (الضيوف)',
    'Invite' => 'دعوة',
    'Invite and request' => ' دعوة و طلب',
    'Invite by email' => 'دعوة بواسطة البريد الالكترونى',
    'Invites' => 'الدعوات',
    'Join Policy' => 'سياسة الانضمام',
    'Last Visit' => 'آخر زيارة',
    'Login' => 'تسجيل الدخول',
    'Member since' => 'عضو منذ',
    'Members' => 'الأعضاء',
    'Moderator:' => 'رئيس الجلسة:',
    'Moderators' => 'المشرفون',
    'My Space List' => 'قائمة الباحة الخاصة بي',
    'My space summary' => 'ملخص الباحة الخاص بي',
    'Name' => 'الاسم',
    'New user by e-mail (comma separated)' => 'مستخدم جديد عبر البريد الإلكتروني (مفصولة بفواصل)',
    'New user?' => 'مستخدم جديد؟',
    'No spaces found.' => 'لم يتم العثور على باحات.',
    'Only by invite' => 'فقط عن طريق الدعوة',
    'Originator User ID' => 'معرف مستخدم المنشئ',
    'Owner' => 'صاحب',
    'Owner:' => 'صاحب:',
    'Pick users' => 'اختر المستخدمين',
    'Please shortly introduce yourself, to become an approved member of this space.' => 'يُرجى تقديم نفسك قريبًا لتصبح عضوًا معتمدًا في هذه الباحة.',
    'Posts' => 'المنشورات',
    'Private' => 'خاص',
    'Private (Invisible)' => 'خاص (غير مرئي)',
    'Public' => 'عام',
    'Public (Members & Guests)' => 'العامة (الأعضاء والضيوف)',
    'Public (Members only)' => 'عام (للأعضاء فقط)',
    'Public (Registered users only)' => 'عام (المستخدمون المسجلون فقط)',
    'Request Message' => 'طلب رسالة',
    'Role' => 'وظيفة',
    'See all' => 'اظهار الكل',
    'Select all registered users' => 'حدد جميع المستخدمين المسجلين',
    'Send' => 'ارسل',
    'Settings' => 'الإعدادات',
    'Show all' => 'عرض الكل',
    'Sorry, you are not allowed to leave this space!' => 'عذرا ، لا يسمح لك بمغادرة هذه الباحة!',
    'Sorting' => 'الترتيب',
    'Space' => 'الباحة',
    'Space directory' => 'دليل الباحة',
    'Space is invisible!' => 'الباحة غير مرئي!',
    'Spaces' => 'الباحات',
    'Status' => 'الحالة',
    'Stream' => 'استريم',
    'Tags' => 'الأوسمة',
    'There is no pending invite!' => 'لا يوجد دعوة معلقة!',
    'This action is only available for workspace members!' => 'هذا الإجراء متاح فقط لأعضاء مساحة العمل!',
    'This user is already a member of this space.' => 'هذا المستخدم عضو بالفعل في هذه المساحة.',
    'This user is not a member of this space.' => 'هذا المستخدم ليس عضوا في هذه المساحة.',
    'To invite users to this space, please type their names below to find and pick them.' => 'لدعوة المستخدمين إلى هذه المساحة ، يرجى كتابة أسمائهم أدناه للعثور عليهم واختيارهم.',
    'Updated At' => 'تم التحديث في',
    'Updated By' => 'تم التحديث بواسطة',
    'Updated by' => 'تم التحديث بواسطة',
    'User \'{username}\' is already a member of this space!' => 'المستخدم \'{username} \' عضو بالفعل في هذه المساحة!',
    'User invitations have been added to the queue' => 'تمت إضافة دعوات المستخدم إلى قائمة الانتظار',
    'User memberships have been added to the queue' => 'تمت إضافة عضويات المستخدم إلى قائمة الانتظار',
    'User not found!' => 'لم يتم إيجاد العضو',
    'Users' => 'المستخدمون',
    'Users has been invited.' => 'تمت دعوة المستخدمين.',
    'Visibility' => 'الرؤية',
    'Visible for all (members and guests)' => 'مرئي للجميع (الأعضاء والضيوف)',
    'You are not allowed to join this space!' => 'غير مسموح لك بالانضمام إلى هذه المساحة!',
    'You can also invite external users, which are not registered now. Just add their e-mail addresses separated by comma.' => 'يمكنك أيضًا دعوة مستخدمين خارجيين غير مسجلين الآن. ما عليك سوى إضافة عناوين بريدهم الإلكتروني مفصولة بفواصل.',
    'You cannot create private visible spaces!' => 'لا يمكنك إنشاء مساحات مرئية خاصة!',
    'You cannot create public visible spaces!' => 'لا يمكنك إنشاء مساحات مرئية عامة!',
    'You need to login to view contents of this space!' => 'أنت بحاجة إلى تسجيل الدخول لعرض محتويات هذه المساحة!',
    'Your request was successfully submitted to the space administrators.' => 'تم إرسال طلبك بنجاح إلى مسؤولي الباحة.',
    '{count} members' => '{count} أعضاء',
    '{email} is not valid!' => '{email} غير صحيح!',
    '<strong>About</strong> the Space' => '',
    '<strong>About</strong> your membership' => '',
    '<strong>Space</strong> tags' => '',
    '<strong>Spaces</strong>' => '',
    'Any' => '',
    'Blocked users' => '',
    'By Name' => '',
    'Find Spaces by their description or by their tags' => '',
    'Guests' => '',
    'Hide Members sidebar in the stream page.' => '',
    'Join' => '',
    'Max. 100 characters.' => '',
    'Member' => '',
    'Moderator' => '',
    'Neither..nor' => '',
    'Newest first' => '',
    'No results found!' => '',
    'Oldest first' => '',
    'Pending' => '',
    'Search...' => '',
    'Settings could not be saved!' => '',
    'Shown on About Page.' => '',
    'Space Visibility' => '',
    'Try other keywords or remove filters.' => '',
    'Would you like to end your membership in Space {spaceName}?' => '',
    'Would you like to unfollow Space {spaceName}?' => '',
    'Would you like to unfollow {userName}?' => '',
    'Would you like to withdraw your request to join Space {spaceName}?' => '',
];

==> humhub-1.16.0-beta.2.tar.gz: humhub-1.16.0-beta.2/protected/humhub/modules/space/messages/ar/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '<b>هذه المساحة لا تزال فارغة!</b>',
    '<b>This space is still empty!</b><br>Start by posting something here...' => 'هذه الباحة تخلو من المحتويات! <br>يمكنك البدء و كتابة شيء ما...',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>أنت لست عضوًا في هذه المساحة ولا يوجد محتوى عام حتى الآن!</b>',
    '<strong>Confirm</strong> image deletion' => 'حذف الصورة <strong>تأكيد</strong>',
    '<strong>Invite</strong> members' => 'أفراد <strong>دعوة</strong>',
    '<strong>New</strong> member request' => 'طلب عضو <strong>جديد</strong>',
    '<strong>New</strong> spaces' => 'باحة <strong>جديد</strong>',
    '<strong>Request</strong> Membership' => 'عضوية الفضاء <strong>طلب</strong> ',
    '<strong>Space</strong> followers' => 'المتابعون <strong>باحة</strong>',
    '<strong>Space</strong> members' => 'الاعضاء <strong>باحة</strong>',
    '<strong>Space</strong> menu' => 'المنيو <strong>باحة</strong>',
    'About' => 'عن',
    'Accept' => 'موافقة',
    'Accept Invite' => 'قبول دعوة',
    'Access to this Space is restricted. Please introduce yourself to become a member.' => 'يُرجى تقديم نفسك قريبًا لتصبح عضوًا معتمدًا في هذه الباحة.',
    'Add users without invitation' => 'أضف مستخدمين بدون دعوة',
    'Admin' => 'مشرف',
    'Administrator:' => 'مدير:',
    'Administrators' => 'المسؤولون',
    'Archived' => 'أرشيف',
    'As owner you cannot revoke your membership!' => 'كمالك لا يمكنك إلغاء عضويتك!',
    'Cancel' => 'إلغاء',
    'Close' => 'اغلاق',
    'Color' => 'الون',
    'Could not request membership!' => 'تعذر طلب العضوية!',
    'Created At' => 'أنشئت في',
    'Created By' => 'تم وضعه بواسطة',
    'Decline' => 'رفض',
    'Decline Invite' => 'رفض الدعوة',
    'Default' => 'الإفتراضي',
    'Default content visibility' => 'رؤية المحتوى الافتراضي',
    'Delete' => 'حذف',
    'Description' => 'توضيج',
    'Do you really want to delete your profile image?' => 'هل تريد حقًا حذف صورة ملفك الشخصي؟',
    'Do you really want to delete your title image?' => 'هل تريد حقًا حذف صورة العنوان؟',
    'Done' => 'تم',
    'Email addresses' => 'البريد الالكترونى',
    'Everyone can enter' => 'يمكن للجميع الدخول',
    'Follow' => 'متابعة',
    'Followers' => 'متابعون',
    'Following' => 'التالية',
    'Homepage' => 'الصفحة الرئيسية',
    'Invite' => 'دعوة',
    'Invite and request' => ' دعوة و طلب',
    'Invite by email' => 'دعوة بواسطة البريد الالكترونى',
    'Invites' => 'الدعوات',
    'Join Policy' => 'سياسة الانضمام',
    'Last Visit' => 'آخر زيارة',
    'Leave' => 'مغادرة',
    'Login' => 'تسجيل الدخول',
    'Member since' => 'عضو منذ',
    'Members' => 'الأعضاء',
    'Moderator:' => 'رئيس الجلسة:',
    'Moderators' => 'المشرفون',
    'My Space List' => 'قائمة الباحة الخاصة بي',
    'My space summary' => 'ملخص الباحة الخاص بي',
    'Name' => 'الاسم',
    'New user by e-mail (comma separated)' => 'مستخدم جديد عبر البريد الإلكتروني (مفصولة بفواصل)',
    'New user?' => 'مستخدم جديد؟',
    'No spaces found.' => 'لم يتم العثور على باحات.',
    'Only by invite' => 'فقط عن طريق الدعوة',
    'Originator User ID' => 'معرف مستخدم المنشئ',
    'Owner' => 'صاحب',
    'Owner:' => 'صاحب:',
    'Pick users' => 'اختر المستخدمين',
    'Posts' => 'المنشورات',
    'Private' => 'خاص',
    'Private (Invisible)' => 'خاص (غير مرئي)',
    'Public' => 'عام',
    'Public (Members & Guests)' => 'العامة (الأعضاء والضيوف)',
    'Public (Members only)' => 'عام (للأعضاء فقط)',
    'Public (Registered users only)' => 'عام (المستخدمون المسجلون فقط)',
    'Request Message' => 'طلب رسالة',
    'Role' => 'وظيفة',
    'See all' => 'اظهار الكل',
    'Select all registered users' => 'حدد جميع المستخدمين المسجلين',
    'Send' => 'ارسل',
    'Settings' => 'الإعدادات',
    'Show all' => 'عرض الكل',
    'Sorry, you are not allowed to leave this space!' => 'عذرا ، لا يسمح لك بمغادرة هذه الباحة!',
    'Sorting' => 'الترتيب',
    'Space' => 'الباحة',
    'Space directory' => 'دليل الباحة',
    'Space is invisible!' => 'الباحة غير مرئي!',
    'Spaces' => 'الباحات',
    'Status' => 'الحالة',
    'Stream' => 'استريم',
    'Tags' => 'الأوسمة',
    'There is no pending invite!' => 'لا يوجد دعوة معلقة!',
    'This action is only available for workspace members!' => 'هذا الإجراء متاح فقط لأعضاء مساحة العمل!',
    'This user is already a member of this space.' => 'هذا المستخدم عضو بالفعل في هذه المساحة.',
    'This user is not a member of this space.' => 'هذا المستخدم ليس عضوا في هذه المساحة.',
    'To invite users to this space, please type their names below to find and pick them.' => 'لدعوة المستخدمين إلى هذه المساحة ، يرجى كتابة أسمائهم أدناه للعثور عليهم واختيارهم.',
    'Updated At' => 'تم التحديث في',
    'Updated By' => 'تم التحديث بواسطة',
    'Updated by' => 'تم التحديث بواسطة',
    'User \'{username}\' is already a member of this space!' => 'المستخدم \'{username} \' عضو بالفعل في هذه المساحة!',
    'User invitations have been added to the queue' => 'تمت إضافة دعوات المستخدم إلى قائمة الانتظار',
    'User memberships have been added to the queue' => 'تمت إضافة عضويات المستخدم إلى قائمة الانتظار',
    'User not found!' => 'لم يتم إيجاد العضو',
    'Users' => 'المستخدمون',
    'Users has been invited.' => 'تمت دعوة المستخدمين.',
    'Visibility' => 'الرؤية',
    'Visible for all (members and guests)' => 'مرئي للجميع (الأعضاء والضيوف)',
    'You are not allowed to join this space!' => 'غير مسموح لك بالانضمام إلى هذه المساحة!',
    'You cannot create private visible spaces!' => 'لا يمكنك إنشاء مساحات مرئية خاصة!',
    'You cannot create public visible spaces!' => 'لا يمكنك إنشاء مساحات مرئية عامة!',
    'You need to login to view contents of this space!' => 'أنت بحاجة إلى تسجيل الدخول لعرض محتويات هذه المساحة!',
    'Your Message' => 'رسالة التطبيق',
    'Your request was successfully submitted to the space administrators.' => 'تم إرسال طلبك بنجاح إلى مسؤولي الباحة.',
    '{count} members' => '{count} أعضاء',
    '{email} is not valid!' => '{email} غير صحيح!',
    '<strong>About</strong> the Space' => '',
    '<strong>About</strong> your membership' => '',
    '<strong>Leave</strong> Space' => '',
    '<strong>Space</strong> tags' => '',
    '<strong>Spaces</strong>' => '',
    'Advanced Spaces Search' => '',
    'Any' => '',
    'Blocked users' => '',
    'By Name' => '',
    'Change visibility' => '',
    'Create new link' => '',
    'Find Spaces by their description or by their tags' => '',
    'Guests' => '',
    'Hide About Page' => '',
    'Hide Activity Sidebar Widget' => '',
    'Hide Followers' => '',
    'Hide Members' => '',
    'Homepage (Non-members)' => '',
    'I want to become a member because...' => '',
    'Incorrect name, try again.' => '',
    'Invite by link' => '',
    'Invite link' => '',
    'Join' => '',
    'Max. 100 characters.' => '',
    'Member' => '',
    'Moderator' => '',
    'Name / Sort order' => '',
    'Neither..nor' => '',
    'Newest first' => '',
    'No results found!' => '',
    'Oldest first' => '',
    'Pending' => '',
    'Please note that any links you have previously created will become invalid as soon as you create a new one. Would you like to proceed?' => '',
    'Search...' => '',
    'Send the link via email' => '',
    'Settings could not be saved!' => '',
    'Show as List' => '',
    'Shown on About Page.' => '',
    'Space Name' => '',
    'Space Visibility' => '',
    'The default homepage for members of this Space' => '',
    'The default homepage for non-members and guests visiting this Space' => '',
    'The secure link has been copied in your clipboard!' => '',
    'Try other keywords or remove filters.' => '',
    'Warning: If you change the visibility settings of a Space from public to private, all content within that Space, including posts, comments, attachments etc. will also be set to private. This means that non-members will no longer be able to see, access, or interact with any of the content within that Space.' => '',
    'Would you like to end your membership in Space {spaceName}?' => '',
    'Would you like to unfollow Space {spaceName}?' => '',
    'Would you like to unfollow {userName}?' => '',
    'Would you like to withdraw your request to join Space {spaceName}?' => '',
    'You can also invite external users by email, which are not registered now. Just add their e-mail addresses separated by comma.' => '',
    'You can invite external users who are currently not registered via link. All you need to do is share this secure link with them.' => '',
];
